from fastapi import FastAPI
import logging
from contextlib import asynccontextmanager


from router_questions import router as questions_router
from router_class import router as class_router
from router_flight import router as flight_router
from router_reviews import router as reviews_router
from router_statistics import router as statistic_router

# Настройка логирования
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

@asynccontextmanager
async def lifespan(app: FastAPI):
    logger.info("База данных готова к работе")
    yield
    logger.info("Выключение")

app = FastAPI(lifespan=lifespan)
app.include_router(questions_router)
app.include_router(class_router)
app.include_router(flight_router)
app.include_router(reviews_router)
app.include_router(statistic_router)

